@@ -586,6 +586,34 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeBasicDeviceStatus(self, request):
+        """获取基础防护攻击状态
+
+        :param request: Request instance for DescribeBasicDeviceStatus.
+        :type request: :class:`tencentcloud.antiddos.v20200309.models.DescribeBasicDeviceStatusRequest`
+        :rtype: :class:`tencentcloud.antiddos.v20200309.models.DescribeBasicDeviceStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeBasicDeviceStatus", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeBasicDeviceStatusResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeBlackWhiteIpList(self, request):
         """获取DDoS防护的IP黑白名单
 
@@ -1146,6 +1174,34 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyL7RulesEdge(self, request):
+        """修改边界防护L7转发规则
+
+        :param request: Request instance for ModifyL7RulesEdge.
+        :type request: :class:`tencentcloud.antiddos.v20200309.models.ModifyL7RulesEdgeRequest`
+        :rtype: :class:`tencentcloud.antiddos.v20200309.models.ModifyL7RulesEdgeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyL7RulesEdge", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyL7RulesEdgeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyPacketFilterConfig(self, request):
         """修改DDoS防护的特征过滤规则
 
