@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -31,6 +33,13 @@ class AcceptDirectConnectTunnelRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.DirectConnectTunnelId = params.get("DirectConnectTunnelId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AcceptDirectConnectTunnelResponse(AbstractModel):
@@ -107,6 +116,13 @@ class AccessPoint(AbstractModel):
             self.Coordinate._deserialize(params.get("Coordinate"))
         self.City = params.get("City")
         self.Area = params.get("Area")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ApplyInternetAddressRequest(AbstractModel):
@@ -136,6 +152,13 @@ class ApplyInternetAddressRequest(AbstractModel):
         self.MaskLen = params.get("MaskLen")
         self.AddrType = params.get("AddrType")
         self.AddrProto = params.get("AddrProto")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ApplyInternetAddressResponse(AbstractModel):
@@ -179,6 +202,13 @@ class BFDInfo(AbstractModel):
     def _deserialize(self, params):
         self.ProbeFailedTimes = params.get("ProbeFailedTimes")
         self.Interval = params.get("Interval")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class BGPStatus(AbstractModel):
@@ -200,6 +230,13 @@ class BGPStatus(AbstractModel):
     def _deserialize(self, params):
         self.TencentAddressBgpState = params.get("TencentAddressBgpState")
         self.TencentBackupAddressBgpState = params.get("TencentBackupAddressBgpState")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class BgpPeer(AbstractModel):
@@ -221,6 +258,13 @@ class BgpPeer(AbstractModel):
     def _deserialize(self, params):
         self.Asn = params.get("Asn")
         self.AuthKey = params.get("AuthKey")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Coordinate(AbstractModel):
@@ -242,6 +286,13 @@ class Coordinate(AbstractModel):
     def _deserialize(self, params):
         self.Lat = params.get("Lat")
         self.Lng = params.get("Lng")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateDirectConnectRequest(AbstractModel):
@@ -324,6 +375,13 @@ class CreateDirectConnectRequest(AbstractModel):
         self.FaultReportContactPerson = params.get("FaultReportContactPerson")
         self.FaultReportContactNumber = params.get("FaultReportContactNumber")
         self.SignLaw = params.get("SignLaw")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateDirectConnectResponse(AbstractModel):
@@ -438,6 +496,13 @@ STATIC：静态
         self.CustomerAddress = params.get("CustomerAddress")
         self.TencentBackupAddress = params.get("TencentBackupAddress")
         self.CloudAttachId = params.get("CloudAttachId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateDirectConnectTunnelResponse(AbstractModel):
@@ -476,6 +541,13 @@ class DeleteDirectConnectRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.DirectConnectId = params.get("DirectConnectId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteDirectConnectResponse(AbstractModel):
@@ -510,6 +582,13 @@ class DeleteDirectConnectTunnelRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.DirectConnectTunnelId = params.get("DirectConnectTunnelId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteDirectConnectTunnelResponse(AbstractModel):
@@ -554,6 +633,13 @@ class DescribeAccessPointsRequest(AbstractModel):
         self.RegionId = params.get("RegionId")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAccessPointsResponse(AbstractModel):
@@ -601,6 +687,13 @@ class DescribeDirectConnectTunnelExtraRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.DirectConnectTunnelId = params.get("DirectConnectTunnelId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeDirectConnectTunnelExtraResponse(AbstractModel):
@@ -662,6 +755,13 @@ class DescribeDirectConnectTunnelsRequest(AbstractModel):
         self.DirectConnectTunnelIds = params.get("DirectConnectTunnelIds")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeDirectConnectTunnelsResponse(AbstractModel):
@@ -726,6 +826,13 @@ class DescribeDirectConnectsRequest(AbstractModel):
         self.DirectConnectIds = params.get("DirectConnectIds")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeDirectConnectsResponse(AbstractModel):
@@ -844,6 +951,13 @@ class DescribeInternetAddressRequest(AbstractModel):
                 obj = Filter()
                 obj._deserialize(item)
                 self.Filters.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeInternetAddressResponse(AbstractModel):
@@ -948,6 +1062,13 @@ route-subnet：路由cidr，取值如：192.68.1.0/24
                 self.Filters.append(obj)
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribePublicDirectConnectTunnelRoutesResponse(AbstractModel):
@@ -1070,10 +1191,10 @@ class DirectConnect(AbstractModel):
         :param LocalZone: 物理专线是否为LocalZone
 注意：此字段可能返回 null，表示取不到有效值。
         :type LocalZone: bool
-        :param VlanZeroDirectConnectTunnelCount: 该物理专线下vlan 0的专线通道数量
+        :param VlanZeroDirectConnectTunnelCount: 该物理专线下vlan 0的专用通道数量
 注意：此字段可能返回 null，表示取不到有效值。
         :type VlanZeroDirectConnectTunnelCount: int
-        :param OtherVlanDirectConnectTunnelCount: 该物理专线下非vlan 0的专线通道数量
+        :param OtherVlanDirectConnectTunnelCount: 该物理专线下非vlan 0的专用通道数量
 注意：此字段可能返回 null，表示取不到有效值。
         :type OtherVlanDirectConnectTunnelCount: int
         :param MinBandwidth: 物理专线最小带宽
@@ -1152,6 +1273,13 @@ class DirectConnect(AbstractModel):
         self.VlanZeroDirectConnectTunnelCount = params.get("VlanZeroDirectConnectTunnelCount")
         self.OtherVlanDirectConnectTunnelCount = params.get("OtherVlanDirectConnectTunnelCount")
         self.MinBandwidth = params.get("MinBandwidth")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DirectConnectTunnel(AbstractModel):
@@ -1318,6 +1446,13 @@ REJECTED:拒绝
         self.TencentBackupAddress = params.get("TencentBackupAddress")
         self.SignLaw = params.get("SignLaw")
         self.CloudAttachId = params.get("CloudAttachId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DirectConnectTunnelExtra(AbstractModel):
@@ -1418,6 +1553,9 @@ REJECTED:拒绝
         :param CustomerIPv6Address: 用户侧互联IPv6地址
 注意：此字段可能返回 null，表示取不到有效值。
         :type CustomerIPv6Address: str
+        :param JumboEnable: 专用通道是否支持巨帧。1 支持，0 不支持
+注意：此字段可能返回 null，表示取不到有效值。
+        :type JumboEnable: int
         """
         self.DirectConnectTunnelId = None
         self.DirectConnectId = None
@@ -1457,6 +1595,7 @@ REJECTED:拒绝
         self.TencentBackupIPv6Address = None
         self.BgpIPv6Status = None
         self.CustomerIPv6Address = None
+        self.JumboEnable = None
 
 
     def _deserialize(self, params):
@@ -1518,10 +1657,18 @@ REJECTED:拒绝
             self.BgpIPv6Status = BGPStatus()
             self.BgpIPv6Status._deserialize(params.get("BgpIPv6Status"))
         self.CustomerIPv6Address = params.get("CustomerIPv6Address")
+        self.JumboEnable = params.get("JumboEnable")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DirectConnectTunnelRoute(AbstractModel):
-    """专线通道路由
+    """专用通道路由
 
     """
 
@@ -1555,6 +1702,13 @@ class DirectConnectTunnelRoute(AbstractModel):
         self.Status = params.get("Status")
         self.ASPath = params.get("ASPath")
         self.NextHop = params.get("NextHop")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DisableInternetAddressRequest(AbstractModel):
@@ -1572,6 +1726,13 @@ class DisableInternetAddressRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DisableInternetAddressResponse(AbstractModel):
@@ -1606,6 +1767,13 @@ class EnableInternetAddressRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EnableInternetAddressResponse(AbstractModel):
@@ -1644,6 +1812,13 @@ class Filter(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Values = params.get("Values")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class InternetAddressDetail(AbstractModel):
@@ -1721,6 +1896,13 @@ class InternetAddressDetail(AbstractModel):
         self.AppId = params.get("AppId")
         self.AddrProto = params.get("AddrProto")
         self.ReserveTime = params.get("ReserveTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class InternetAddressStatistics(AbstractModel):
@@ -1744,6 +1926,13 @@ class InternetAddressStatistics(AbstractModel):
     def _deserialize(self, params):
         self.Region = params.get("Region")
         self.SubnetNum = params.get("SubnetNum")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyDirectConnectAttributeRequest(AbstractModel):
@@ -1809,6 +1998,13 @@ class ModifyDirectConnectAttributeRequest(AbstractModel):
         self.FaultReportContactNumber = params.get("FaultReportContactNumber")
         self.SignLaw = params.get("SignLaw")
         self.Bandwidth = params.get("Bandwidth")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyDirectConnectAttributeResponse(AbstractModel):
@@ -1878,6 +2074,13 @@ class ModifyDirectConnectTunnelAttributeRequest(AbstractModel):
         self.CustomerAddress = params.get("CustomerAddress")
         self.Bandwidth = params.get("Bandwidth")
         self.TencentBackupAddress = params.get("TencentBackupAddress")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyDirectConnectTunnelAttributeResponse(AbstractModel):
@@ -1935,6 +2138,10 @@ class ModifyDirectConnectTunnelExtraRequest(AbstractModel):
         :type IPv6Enable: int
         :param CustomerIDCRoutes: 去往用户侧的路由信息
         :type CustomerIDCRoutes: list of RouteFilterPrefix
+        :param JumboEnable: 是否开启巨帧
+1：开启
+0：不开启
+        :type JumboEnable: int
         """
         self.DirectConnectTunnelId = None
         self.Vlan = None
@@ -1951,6 +2158,7 @@ class ModifyDirectConnectTunnelExtraRequest(AbstractModel):
         self.NqaInfo = None
         self.IPv6Enable = None
         self.CustomerIDCRoutes = None
+        self.JumboEnable = None
 
 
     def _deserialize(self, params):
@@ -1982,6 +2190,14 @@ class ModifyDirectConnectTunnelExtraRequest(AbstractModel):
                 obj = RouteFilterPrefix()
                 obj._deserialize(item)
                 self.CustomerIDCRoutes.append(obj)
+        self.JumboEnable = params.get("JumboEnable")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyDirectConnectTunnelExtraResponse(AbstractModel):
@@ -2024,6 +2240,13 @@ class NQAInfo(AbstractModel):
         self.ProbeFailedTimes = params.get("ProbeFailedTimes")
         self.Interval = params.get("Interval")
         self.DestinationIp = params.get("DestinationIp")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RejectDirectConnectTunnelRequest(AbstractModel):
@@ -2041,6 +2264,13 @@ class RejectDirectConnectTunnelRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.DirectConnectTunnelId = params.get("DirectConnectTunnelId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RejectDirectConnectTunnelResponse(AbstractModel):
@@ -2075,6 +2305,13 @@ class ReleaseInternetAddressRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ReleaseInternetAddressResponse(AbstractModel):
@@ -2109,6 +2346,13 @@ class RouteFilterPrefix(AbstractModel):
 
     def _deserialize(self, params):
         self.Cidr = params.get("Cidr")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Tag(AbstractModel):
@@ -2131,4 +2375,11 @@ class Tag(AbstractModel):
 
     def _deserialize(self, params):
         self.Key = params.get("Key")
-        self.Value = params.get("Value")
\ No newline at end of file
+        self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
