@@ -23,6 +23,9 @@ AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 部分失败（有一部分操作失败）。
+FAILEDOPERATION_PARTIALFAILURE = 'FailedOperation.PartialFailure'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -71,6 +74,9 @@ MISSINGPARAMETER = 'MissingParameter'
 # 缺少必要参数。
 MISSINGPARAMETER_PARAM = 'MissingParameter.Param'
 
+# 操作被拒绝。
+OPERATIONDENIED = 'OperationDenied'
+
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
