@@ -140,7 +140,7 @@ class TrtcClient(AbstractClient):
 
     def DescribeCallDetail(self, request):
         """查询指定时间内的用户列表及用户通话质量数据，可查询14天内数据。DataType 不为null，查询实时数据时，查询起止时间不超过1个小时，每次查询用户不超过6个，支持跨天查询。DataType，UserIds为null时，默认查询6个用户，同时支持每页查询100以内用户个数（PageSize不超过100）。接口用于查询质量问题，不推荐作为计费使用。
-        注意：不建议依赖接口做实时类业务逻辑处理
+        **注意**：该接口只用于历史数据统计或核对数据使用，实时类关键业务逻辑不能使用。
 
         :param request: Request instance for DescribeCallDetail.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeCallDetailRequest`
@@ -370,7 +370,7 @@ class TrtcClient(AbstractClient):
 
     def DescribeRoomInformation(self, request):
         """查询sdkappid下的房间列表。默认返回10条通话，一次最多返回100条通话。可查询14天内的数据。
-        注意：不建议依赖接口做实时类业务逻辑处理
+        **注意**：该接口只用于历史数据统计或核对数据使用，实时类关键业务逻辑不能使用。
 
         :param request: Request instance for DescribeRoomInformation.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRoomInformationRequest`
@@ -463,7 +463,7 @@ class TrtcClient(AbstractClient):
 
     def DescribeUserInformation(self, request):
         """查询指定时间内的用户列表，可查询14天内数据，查询起止时间不超过4小时。默认每页查询6个用户，支持每页最大查询100个用户PageSize不超过100）。
-        注意：不建议依赖接口做实时类业务逻辑处理
+        **注意**：该接口只用于历史数据统计或核对数据使用，实时类关键业务逻辑不能使用。
 
         :param request: Request instance for DescribeUserInformation.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeUserInformationRequest`
